@@ -29,6 +29,7 @@ from .core import (
     __version__,
     asymmetric_logistic,
     exponential,
+    infer_independent,
     inverse_asymmetric_logistic,
     inverse_exponential,
     inverse_log_log_logistic,
@@ -43,7 +44,7 @@ from .core import (
     xlog_logistic,
     ylog_logistic,
 )
-from .optimization import fit_pygmo, fit_scipy
+from .optimization import fit_pygmo, fit_scipy, fit_scipy_global
 from .utils import (
     HAS_PYMC,
     HAS_TENSORS,
