@@ -359,6 +359,33 @@ class TestBaseCalibrationModel:
         numpy.testing.assert_array_equal(em_loaded.cal_dependent, em.cal_dependent)
         pass
 
+    @pytest.mark.parametrize("ndim", [1, 2, 3])
+    def test_save_and_load_attributes_wo_guess(self, ndim):
+        shape = tuple(3 + numpy.arange(ndim))
+        assert len(shape) == ndim
+
+        em = _TestModel()
+        em.theta_fitted = (1, 2, 3)
+        theta_timestamp = em.theta_timestamp
+        em.theta_bounds = ((None, None), (0, 5), (0, 10))
+        em.cal_independent = numpy.random.uniform(0, 10, size=shape)
+        em.cal_dependent = numpy.random.normal(size=len(em.cal_independent))
+
+        # save and load
+        em.save("save_load_test.json")
+        em_loaded = _TestModel.load("save_load_test.json")
+
+        assert isinstance(em_loaded, _TestModel)
+        assert em_loaded.independent_key == em.independent_key
+        assert em_loaded.dependent_key == em.dependent_key
+        assert em_loaded.theta_bounds == em.theta_bounds
+        assert em_loaded.theta_fitted == em.theta_fitted
+        assert em_loaded.theta_timestamp is not None
+        assert em_loaded.theta_timestamp == theta_timestamp
+        numpy.testing.assert_array_equal(em_loaded.cal_independent, em.cal_independent)
+        numpy.testing.assert_array_equal(em_loaded.cal_dependent, em.cal_dependent)
+        pass
+
     def test_objective(self):
         cm = _TestPolynomialModel(mu_degree=1, scale_degree=0)
         calX = numpy.linspace(1, 10, 5)
@@ -1203,7 +1230,7 @@ class TestOptimization:
         theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
         common = dict(model=em, independent=x, dependent=y)
         for fit in (calibr8.fit_scipy, calibr8.fit_pygmo):
-            # wrong theta
+            # wrong guess
             with pytest.raises(ValueError):
                 fit(**common, theta_guess=numpy.ones(14), theta_bounds=[(-5, 5)] * len(theta))
             # wrong bounds
@@ -1285,6 +1312,58 @@ class TestOptimization:
         numpy.testing.assert_array_equal(em.cal_dependent, y)
         pass
 
+    def test_fit_scipy_global(self, caplog):
+        numpy.random.seed(2345)
+        theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
+        theta_fit, history = calibr8.fit_scipy_global(
+            em,
+            independent=x,
+            dependent=y,
+            theta_bounds=[(-10, 10)] * len(theta_mu) + [(0.001, 5), (1, 20)],
+        )
+        for actual, desired, atol in zip(theta_fit, theta, [0.10, 0.05, 0.2, 2]):
+            numpy.testing.assert_allclose(actual, desired, atol=atol)
+        assert isinstance(history, list)
+        numpy.testing.assert_array_equal(em.theta_fitted, theta_fit)
+        numpy.testing.assert_array_equal(theta_fit, history[-1][0])
+        assert em.theta_bounds is not None
+        numpy.testing.assert_array_equal(em.cal_independent, x)
+        numpy.testing.assert_array_equal(em.cal_dependent, y)
+
+        with caplog.at_level(logging.WARNING):
+            x[0] = float("nan")
+            y[-1] = numpy.inf
+            calibr8.fit_scipy_global(
+                em,
+                independent=x,
+                dependent=y,
+                theta_bounds=[(-10, 10)] * len(theta_mu) + [(0.001, 5), (1, 20)],
+            )
+        assert "2 elements" in caplog.text
+        # inf/nan should only be ignored for fitting
+        numpy.testing.assert_array_equal(em.cal_independent, x)
+        numpy.testing.assert_array_equal(em.cal_dependent, y)
+        pass
+
+    def test_global_solver_method_error(self):
+        with pytest.raises(ValueError, match="supported global optimization solver method is"):
+            theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
+            theta_fit, history = calibr8.fit_scipy_global(
+                em,
+                independent=x,
+                dependent=y,
+                theta_bounds=[(-10, 10)] * len(theta_mu) + [(0.001, 5), (1, 20)],
+                method="direct",
+            )
+            pass
+
+    def test_global_fit_checks_bounds_count(self):
+        theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
+        common = dict(model=em, independent=x, dependent=y)
+        with pytest.raises(ValueError):
+            calibr8.fit_scipy_global(**common, theta_bounds=[(-5, 5)] * 14)
+        return
+
 
 class TestContribStudentT:
     def test_cant_instantiate_base_models(self):
@@ -1553,3 +1632,20 @@ class TestBaseModels:
         with pytest.raises(ValueError, match="are useless"):
             _TestModel(mu_degree=0)
         pass
+
+
+class TestScaleDegreeWarning:
+    def test_negative_value(self):
+        with pytest.raises(ValueError, match="natural number!"):
+            _TestPolynomialModel(scale_degree=-1)
+            pass
+
+    def test_value_is_none(self):
+        with pytest.raises(ValueError, match="natural number!"):
+            _TestPolynomialModel(scale_degree=None)
+            pass
+
+    def test_high_scale_value(self):
+        with pytest.warns(UserWarning, match="Consider a lower value."):
+            _TestPolynomialModel(scale_degree=2)
+        pass
